@@ -41,10 +41,12 @@ regex_example <- paste(regex_example_vec, collapse = "|")
 #'
 #' # {fusen} steps
 #' dev_file <- add_flat_template(template = "full", pkg = dummypackage, overwrite = TRUE)
-#' flat_file <- dev_file[grepl('flat', dev_file)]
+#' flat_file <- dev_file[grepl("flat", dev_file)]
 #' fill_description(pkg = dummypackage, fields = list(Title = "Dummy Package"))
-#' inflate(pkg = dummypackage, flat_file = flat_file,
-#'   vignette_name = "Exploration of my Data", check = FALSE)
+#' inflate(
+#'   pkg = dummypackage, flat_file = flat_file,
+#'   vignette_name = "Exploration of my Data", check = FALSE
+#' )
 #'
 #' # Explore directory of the package
 #' # browseURL(dummypackage)
@@ -54,34 +56,71 @@ regex_example <- paste(regex_example_vec, collapse = "|")
 #' # pkgdown::build_site(dummypackage)
 #' # Delete dummy package
 #' unlink(dummypackage, recursive = TRUE)
-inflate <- function(pkg = ".", flat_file = file.path("dev", "flat_full.Rmd"),
+inflate <- function(pkg = ".", flat_file,
                     vignette_name = "Get started",
                     open_vignette = TRUE,
                     check = TRUE, document = TRUE,
                     overwrite = "ask", ...) {
-
   if (!is.null(list(...)[["name"]])) {
-    warning(paste0("The `name` argument to `inflate()` is deprecated since {fusen} version 0.3.0,",
-                   " and will be removed in a future version.",
-                   "\nPlease use `vignette_name = '", list(...)[["name"]],"'` instead.\n"))
+    warning(paste0(
+      "The `name` argument to `inflate()` is deprecated since {fusen} version 0.3.0,",
+      " and will be removed in a future version.",
+      "\nPlease use `vignette_name = '", list(...)[["name"]], "'` instead.\n"
+    ))
     vignette_name <- list(...)[["name"]]
   }
   if (!is.null(list(...)[["rmd"]])) {
-    warning(paste0("The `rmd` argument to `inflate()` is deprecated since {fusen} version 0.3.0,",
-                   " and will be removed in a future version.",
-                   "\nPlease use `flat_file = '", list(...)[["rmd"]],"'` instead.\n"))
+    warning(paste0(
+      "The `rmd` argument to `inflate()` is deprecated since {fusen} version 0.3.0,",
+      " and will be removed in a future version.",
+      "\nPlease use `flat_file = '", list(...)[["rmd"]], "'` instead.\n"
+    ))
     flat_file <- list(...)[["rmd"]]
   }
 
   # Save all open files
   if (
     requireNamespace("rstudioapi") &&
-    rstudioapi::isAvailable() &&
-    rstudioapi::hasFun("documentSaveAll")
+      rstudioapi::isAvailable() &&
+      rstudioapi::hasFun("documentSaveAll")
   ) {
     rstudioapi::documentSaveAll()
   }
 
+
+  # If flat_file empty
+  if (
+    requireNamespace("rstudioapi") &&
+      rstudioapi::isAvailable() &&
+      rstudioapi::hasFun("documentPath")
+  ) {
+    current_file <- rstudioapi::documentPath()
+    if (missing(flat_file) & grepl("^flat.*[.]Rmd$", basename(current_file))) {
+      if (overwrite == "ask") {
+        sure <- paste(
+          "The current file will be inflated:\n",
+          current_file, ".\n",
+          "Are you sure this is what you planned? (y/n)\n"
+        )
+        do_it <- readline(sure) == "y"
+      } else {
+        do_it <- isTRUE(overwrite)
+      }
+      if (do_it) {
+        message("The current file will be inflated: ", current_file)
+        flat_file <- current_file
+      }
+    }
+  }
+
+  if (missing(flat_file)) {
+    stop(
+      "`flat_file` argument is empty. ",
+      "Did you run `inflate()` directly in the console, ",
+      "instead of the one at the bottom of your flat file?"
+    )
+  }
+
   old <- setwd(pkg)
   on.exit(setwd(old))
 
@@ -93,11 +132,11 @@ inflate <- function(pkg = ".", flat_file = file.path("dev", "flat_full.Rmd"),
 
   pkg <- normalizePath(pkg)
   needs_restart <- isFALSE(is_pkg_proj(pkg))
-  flat_file <- normalizePath(flat_file, mustWork = FALSE)
+  flat_file <- normalizePath(flat_file, mustWork = TRUE)
 
   if (!file.exists(file.path(normalizePath(pkg), "DESCRIPTION"))) {
     stop(
-      "DESCRIPTION file does not exist in your directory:", normalizePath(pkg), ".\n",
+      "DESCRIPTION file does not exist in your directory:", normalize_path_winslash(pkg), ".\n",
       "Have you run the content of the 'description' chunk of your {fusen} template?"
     )
   }
@@ -162,32 +201,48 @@ inflate <- function(pkg = ".", flat_file = file.path("dev", "flat_full.Rmd"),
   parsed_tbl$chunk_filename <- unlist(
     lapply(
       parsed_tbl[["options"]],
-      function(x) ifelse(is.null(x[["filename"]]),
-                         NA_character_, gsub('"', '', x[["filename"]])))
+      function(x) {
+        ifelse(is.null(x[["filename"]]),
+          NA_character_, gsub('"', "", x[["filename"]])
+        )
+      }
+    )
   )
   # Define sec_title to group functions in same R file
   sec_title <- paste(parsed_tbl[["sec_h1"]],
-                     parsed_tbl[["sec_h2"]],
-                     sep = "-")
+    parsed_tbl[["sec_h2"]],
+    sep = "-"
+  )
 
   if (length(sec_title) != 0) {
     parsed_tbl$sec_title <- sec_title
   } else {
-    parsed_tbl$sec_title <- "fake-title"
+    parsed_tbl$sec_title <- "fake-section-title"
   }
 
+  # Get flat file path relative to package root
+  # To be inserted in "DO NOT EDIT" comments
+  relative_flat_file <- sub(normalize_path_winslash(pkg), "", normalize_path_winslash(flat_file))
+
   # Check if there are functions ----
-  fun_code <- get_functions(parsed_tbl)
+  fun_code <- get_functions_tests(parsed_tbl)
+
   # Get functions and create R and tests files ----s
   if (!is.null(fun_code)) {
-    create_functions_all(parsed_tbl, fun_code, pkg)
+    create_functions_all(parsed_tbl, fun_code, pkg, relative_flat_file)
   } else {
     message("No chunks named 'function-xx' or 'fun-xx' were found in the Rmarkdown file: ", flat_file)
   }
 
   # Create vignette ----
   if (!(is.null(vignette_name) || is.na(vignette_name) || vignette_name == "")) {
-    create_vignette(parsed_tbl, pkg, vignette_name, open_vignette = open_vignette)
+    create_vignette(
+      parsed_tbl = parsed_tbl,
+      pkg = pkg,
+      relative_flat_file = relative_flat_file,
+      vignette_name = vignette_name,
+      open_vignette = open_vignette
+    )
   } else {
     message("`vignette_name` is empty: no vignette created")
   }
@@ -219,17 +274,19 @@ inflate <- function(pkg = ".", flat_file = file.path("dev", "flat_full.Rmd"),
 #' Create function code, doc and tests ----
 #' @param parsed_tbl tibble of a parsed Rmd
 #' @param fun_code tibble as issued from `get_functions`
+#' @param relative_flat_file Path to the flat file to show in R scripts.
 #' @param pkg Path to package
 #' @importFrom stats na.omit
 #' @noRd
-create_functions_all <- function(parsed_tbl, fun_code, pkg) {
+create_functions_all <- function(parsed_tbl, fun_code, pkg, relative_flat_file) {
   fun_names <- fun_code[["fun_name"]]
 
   if (length(unique(na.omit(fun_names))) != length(na.omit(fun_names))) {
     stop("Some functions names are not unique: ", paste(sort(fun_names), collapse = ", "))
   }
 
-  parsed_tbl <- add_fun_to_parsed(parsed_tbl, fun_code)
+  # Add funs if there are or deal with tests alone
+  parsed_tbl <- add_names_to_parsed(parsed_tbl, fun_code)
 
   # Verify labels are unique
   dev_labels_noex <- c(
@@ -250,51 +307,73 @@ create_functions_all <- function(parsed_tbl, fun_code, pkg) {
       "please rename chunks with 'examples-fun_name' for instance.\n",
       "Duplicates: ",
       paste(labels_in_vignette[duplicated(labels_in_vignette)],
-            collapse = ", "
+        collapse = ", "
       )
     )
   }
 
-  # _Get examples
-  fun_code <- add_fun_code_examples(parsed_tbl, fun_code)
+  # If there are functions
+  if (nrow(fun_code) != 0) {
+    # _Get examples
+    fun_code <- add_fun_code_examples(parsed_tbl, fun_code)
 
-  # _Create function files in R/
-  # Create R directory if needed
-  R_dir <- file.path(pkg, "R")
-  if (!dir.exists(R_dir)) {
-    dir.create(R_dir)
+    # _Create function files in R/
+    # Create R directory if needed
+    R_dir <- file.path(pkg, "R")
+    if (!dir.exists(R_dir)) {
+      dir.create(R_dir)
+    }
+
+    create_r_files(fun_code, pkg, relative_flat_file)
   }
 
-  create_r_files(fun_code, pkg)
-  create_tests_files(parsed_tbl, pkg)
+  # If there are tests
+  create_tests_files(parsed_tbl, pkg, relative_flat_file)
 }
 
 #' Get function names ----
 #' @param parsed_tbl tibble of a parsed Rmd
 #' @importFrom parsermd rmd_get_chunk
 #' @noRd
-get_functions <- function(parsed_tbl) {
-
+get_functions_tests <- function(parsed_tbl) {
   which_parsed_fun <- which(!is.na(parsed_tbl$label) &
-                              grepl(regex_functions, parsed_tbl$label))
+    grepl(regex_functions, parsed_tbl$label))
+  which_parsed_tests <- which(!is.na(parsed_tbl$label) &
+    grepl(regex_tests, parsed_tbl$label))
+
   rmd_fun <- parsed_tbl[which_parsed_fun, ]
 
   if (nrow(rmd_fun) != 0) {
+    # At least one function
     fun_code <- lapply(seq_len(nrow(rmd_fun)), function(x) parse_fun(rmd_fun[x, ]))
     fun_code <- do.call("rbind", fun_code)
     fun_code$sec_h1 <- rmd_fun[["sec_h1"]]
     fun_code$sec_title <- rmd_fun[["sec_title"]]
-    return(fun_code)
+  } else if (length(which_parsed_tests) != 0) {
+    # Some tests but no function at all
+    # Needs to be an empty tibble, and not a NULL
+    # 0 lines allows to avoid dealing with examples associated with no functions
+    fun_code <- tibble::tibble(
+      fun_name = character(0),
+      code = list(), # empty to avoid writing R file
+      example_pos_start = logical(0),
+      example_pos_end = logical(0),
+      rox_filename = character(0),
+      sec_title = character(0)
+    )
   } else {
-    return(NULL)
+    fun_code <- NULL
   }
+
+  return(fun_code)
 }
 
 #' create R file with code content and fun name
 #' @param fun_code R code of functions in Rmd as character
 #' @param pkg Path to package
+#' @param relative_flat_file Path to the flat file to show in R scripts
 #' @noRd
-create_r_files <- function(fun_code, pkg) {
+create_r_files <- function(fun_code, pkg, relative_flat_file) {
   fun_code <- fun_code[(lengths(fun_code[["code"]]) != 0), ]
 
   # Combine code with same sec_title to be set in same R file
@@ -314,7 +393,7 @@ create_r_files <- function(fun_code, pkg) {
       cli::cli_alert_warning(paste(basename(r_file), "has been overwritten"))
     }
     lines <- c(
-      "# Generated by fusen: do not edit by hand\n",
+      sprintf("# WARNING - Generated by {fusen} from %s: do not edit by hand\n", relative_flat_file),
       unlist(fun_code[x, ][["code_example"]])
     )
     write_utf8(path = r_file, lines = lines)
@@ -325,69 +404,79 @@ create_r_files <- function(fun_code, pkg) {
 #' Check if there are unit tests ----
 #' @param parsed_tbl tibble of a parsed Rmd
 #' @param pkg Path to package
+#' @param relative_flat_file Path to the flat file to show in R scripts
+#'
 #' @importFrom parsermd rmd_node_code
+#'
 #' @noRd
-create_tests_files <- function(parsed_tbl, pkg) {
+create_tests_files <- function(parsed_tbl, pkg, relative_flat_file) {
+  project_name <- get_pkg_name(pkg = pkg)
+
   rmd_test <- parsed_tbl[!is.na(parsed_tbl$label) &
-                           grepl(regex_tests, parsed_tbl$label), ]
-
-  rmd_test <- rmd_test[!is.na(rmd_test[["fun_name"]]), ]
+    grepl(regex_tests, parsed_tbl$label), ]
 
+  # If there is at least one test
   if (nrow(rmd_test) != 0) {
-    requireNamespace("testthat")
-    # setup testhat
-    test_dir <- file.path(pkg, "tests")
-    if (!dir.exists(test_dir)) {
-      dir.create(test_dir)
-      dir.create(file.path(test_dir, "testthat"))
-      cat(enc2utf8(c(
-        "library(testthat)",
-        paste0("library(", basename(pkg), ")"),
-        "",
-        paste0('test_check("', basename(pkg), '")')
-      )),
-      sep = "\n",
-      file = file.path(test_dir, "testthat.R")
+
+    # Stop for tests chunks not having file_name
+    if (any(is.na(rmd_test[["file_name"]]) | rmd_test[["file_name"]] == "")) {
+      stop(
+        "Some `test` chunks can not be handled: ",
+        paste(rmd_test[["label"]][!is.na(rmd_test[["file_name"]])],
+          collapse = ", "
+        ),
+        ". Please associate these `test` chunks with a `function` chunk, ",
+        "under a section title or with a `filename='mytestfile.R'` chunk option."
       )
     }
 
-    parse_test <- function(x) { # x <- rmd_test[1,]
-      # create R file with code content and fun name
-      file_name <- x[["file_name"]]
-
-      if (is.na(file_name) || file_name == "") {
-        stop("No function found associated to chunk ", x[["label"]])
-      }
-
-      test_file <- file.path(
-        pkg, "tests", "testthat",
-        paste0("test-", asciify_name(file_name), ".R"))
-      if (file.exists(test_file)) {
-        cli::cli_alert_warning(paste(basename(test_file), "has been overwritten"))
-      }
-      lines <- c(
-        "# Generated by fusen: do not edit by hand\n",
-        x[["code"]][[1]])
-      write_utf8(path = test_file, lines = lines)
-      file_name
-    }
-
+    # Group code by file_name
     rmd_test[["code"]] <- rmd_node_code(rmd_test[["ast"]])
-    # Group by file_name
     rmd_test <- group_code(rmd_test, group_col = "file_name", code_col = "code")
 
-    out <- unlist(lapply(seq_len(nrow(rmd_test)),
-                         function(x) parse_test(rmd_test[x, ])))
+    # Filter if code is still empty after code grouped
+    rmd_test[["is_empty"]] <- lapply(
+      rmd_test[["code"]], function(x) grepl("^\\s*$", paste(x, collapse = ""))
+    ) %>%
+      unlist()
+    rmd_test <- rmd_test[!rmd_test[["is_empty"]], ]
+
+    if (nrow(rmd_test) != 0) {
+      # Add directory
+      requireNamespace("testthat")
+
+      # setup testhat
+      test_dir <- file.path(pkg, "tests")
+      if (!dir.exists(test_dir)) {
+        dir.create(test_dir)
+        dir.create(file.path(test_dir, "testthat"))
+        cat(enc2utf8(c(
+          "library(testthat)",
+          paste0("library(", project_name, ")"),
+          "",
+          paste0('test_check("', project_name, '")')
+        )),
+        sep = "\n",
+        file = file.path(test_dir, "testthat.R")
+        )
+      }
+
+      out <- unlist(lapply(
+        seq_len(nrow(rmd_test)),
+        function(x) parse_test(rmd_test[x, ], pkg, relative_flat_file)
+      ))
+    }
   }
 }
 
 #' Create vignette
 #' @param parsed_tbl tibble of a parsed Rmd
 #' @param pkg Path to package
+#' @param relative_flat_file Path to the flat file to show in R scripts.
 #' @param vignette_name Name of the resulting vignette
 #' @param open_vignette Logical. Whether to open vignette file
 #' @noRd
-create_vignette <- function(parsed_tbl, pkg, vignette_name, open_vignette = TRUE) {
+create_vignette <- function(parsed_tbl, pkg, relative_flat_file, vignette_name, open_vignette = TRUE) {
   old_proj <- usethis::proj_get()
 
   if (normalizePath(old_proj) != normalizePath(pkg)) {
@@ -413,9 +502,10 @@ create_vignette <- function(parsed_tbl, pkg, vignette_name, open_vignette = TRUE
     ), collapse = "|")
   vignette_tbl <- parsed_tbl[
     !(grepl(not_in_vignette, parsed_tbl[["label"]]) |
-        grepl("rmd_yaml_list", parsed_tbl[["type"]])),
+      grepl("rmd_yaml_list", parsed_tbl[["type"]])),
   ]
 
+  flat_yaml <- parsed_tbl[grepl("rmd_yaml_list", parsed_tbl[["type"]]), ]
   # Make chunk names unique
   # vignette_tbl[["label"]][grepl("unnamed", vignette_tbl[["label"]])] <-
   #   gsub("unnamed-", "parsermd-", vignette_tbl[["label"]][grepl("unnamed", vignette_tbl[["label"]])])
@@ -444,33 +534,41 @@ create_vignette <- function(parsed_tbl, pkg, vignette_name, open_vignette = TRUE
   cleaned_vignette_name <- asciify_name(vignette_name)
   vignette_file <- file.path("vignettes", paste0(cleaned_vignette_name, ".Rmd"))
 
-  # usethis::use_vignette(name = cleaned_vignette_name, title = vignette_name)
-  # if (!file.exists(vignette_file)) {
-  #   stop(
-  #     "Vignette could not be filled because of naming problem.",
-  #     "Have you used some special characters in `vignette_name`?"
-  #   )
-  # }
+  # Yaml info
+  yaml_options <- flat_yaml[["ast"]][[1]]
+  # Vignette
+  # Copied from usethis::use_vignette() to allow to not open vignette created
+  # usethis:::use_dependency("knitr", "Suggests")
+  getFromNamespace("use_dependency", "usethis")("knitr", "Suggests")
+  getFromNamespace("use_description_field", "usethis")("VignetteBuilder", "knitr", overwrite = TRUE)
+  usethis::use_git_ignore("inst/doc")
 
   # Vignette head
-  head <- create_vignette_head(pkg = pkg, vignette_name = vignette_name)
+  head <- create_vignette_head(
+    pkg = pkg,
+    vignette_name = vignette_name,
+    yaml_options = yaml_options
+  )
 
   # Write vignette
-  if (nrow(vignette_tbl) == 0) {
-    lines <- c(head,
-               "",
-               "<!-- This vignette is generated by fusen: do not edit by hand -->\n"
+  lines <- c(
+    head,
+    "",
+    sprintf(
+      "<!-- WARNING - This vignette is generated by {fusen} from %s: do not edit by hand -->\n",
+      relative_flat_file
     )
-  } else {
+  )
+  if (nrow(vignette_tbl) != 0) {
     lines <- c(
-      head,
-      "",
-      "<!-- This vignette is generated by fusen: do not edit by hand -->\n",
+      lines,
       parsermd::as_document(vignette_tbl)
     )
   }
+
   write_utf8(path = vignette_file, lines = lines)
 
-  if (isTRUE(open_vignette) & interactive()) {usethis::edit_file(vignette_file)}
+  if (isTRUE(open_vignette) & interactive()) {
+    usethis::edit_file(vignette_file)
+  }
 }
-
